appframe

package
v0.0.0-...-7ff6b7e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: CC0-1.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AppFrame

type AppFrame struct {
	// contains filtered or unexported fields
}

The root model for a TUI program that includes a navstack and an actionbar/command-palette

func NewAppFrame

func NewAppFrame(appName string, components []*con.Component) (output AppFrame)

Initializes an AppFrame with the following components

func (AppFrame) Init

func (m AppFrame) Init() tea.Cmd

Call the Init functions of all the child components (including the actionBar, which will need it for the cursor to blink)

func (AppFrame) Update

func (m AppFrame) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (AppFrame) View

func (m AppFrame) View() string

Jump to