examples

package
v0.0.0-...-6325213 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 11, 2026 License: CC0-1.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

const ANSI_BG_RGB_COLOR = "\x1b[48;2;%d;%d;%dm"
const ANSI_BG_TRANSPARENT_COLOR = "\x1b[0;39;49m"
const ANSI_FG_RGB_COLOR = "\x1b[38;2;%d;%d;%dm▄"
const ANSI_FG_TRANSPARENT_COLOR = "\x1b[0m "
const ANSI_RESET = "\x1b[0m"
const DEFAULT_TERM_COLS = 80
const DEFAULT_TERM_ROWS = 24
const RESIZE_FACTOR_X = 1
const RESIZE_FACTOR_Y = 2
const RESIZE_OFFSET_Y = 8

Variables

var InterpolationType = imaging.Lanczos

Functions

func GetScaledImage

func GetScaledImage(image []byte, scaleFactor int) string

func GetTerminalSize

func GetTerminalSize() (width int, height int, err error)

Types

This section is empty.

Directories

Path Synopsis
colormaker
This code (used in actions.go) serves as a simple example app to demonstrate how actions can be used.
This code (used in actions.go) serves as a simple example app to demonstrate how actions can be used.
linearcontainer
component command
simple command

Jump to