Documentation
¶
Index ¶
Constants ¶
const ANSI_BG_RGB_COLOR = "\x1b[48;2;%d;%d;%dm"
const ANSI_BG_TRANSPARENT_COLOR = "\x1b[0;39;49m"
const ANSI_FG_RGB_COLOR = "\x1b[38;2;%d;%d;%dm▄"
const ANSI_FG_TRANSPARENT_COLOR = "\x1b[0m "
const ANSI_RESET = "\x1b[0m"
const DEFAULT_TERM_COLS = 80
const DEFAULT_TERM_ROWS = 24
const RESIZE_FACTOR_X = 1
const RESIZE_FACTOR_Y = 2
const RESIZE_OFFSET_Y = 8
Variables ¶
var InterpolationType = imaging.Lanczos
Functions ¶
func GetScaledImage ¶
func GetTerminalSize ¶
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
colormaker
This code (used in actions.go) serves as a simple example app to demonstrate how actions can be used.
|
This code (used in actions.go) serves as a simple example app to demonstrate how actions can be used. |
|
linearcontainer
|
|
|
component
command
|
|
|
simple
command
|
|
Click to show internal directories.
Click to hide internal directories.